==> openftd-0.98.6.tar.bz2: openftd-0.98.6/ftd_core/include/ftd_events.h <==
/* ====================================================================
 * FTD4Linux Software License, Version 1.0
 *
 * Copyright (c) 2000-2004 The FTD4Linux Development Team.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        FTD4Linux Development Team (http://www.ftd4linux.2y.net/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "FTD" and "FTD4Linux" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact alguno@ftd4linux.2y.net.
 *
 * 5. Products derived from this software may not be called "FTD4Linux",
 *    nor may "FTD4Linux" appear in their name, without prior written
 *    permission of the FTD4Linux Development Team.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE FTD4LINUX DEVELOPMENT TEAM OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef _FTD_EVENTS_H_
#define _FTD_EVENTS_H_

#include <libxml/tree.h>

#include "ftd_groups.h"

#include "ftd_events_forum.h"

/* ftd_events.c */
FtdEvent        *ftd_event_new(void);

/* ftd_events_parse.c */
FtdErrorCode     ftd_events_list_parse(FtdString *buffer, time_t *lastCheck, FtdList **ret, char **errmsg);
FtdErrorCode     ftd_events_parse(FtdString *buffer, FtdTree **ret_tree, FtdList **ret_list, char **errmsg, gboolean ignore_errors);
FtdEvent        *ftd_events_parse_event(xmlDocPtr, xmlNodePtr);
FtdList         *ftd_events_parse_mp3_tracks(xmlDocPtr, xmlNodePtr);

/* ftd_events_sort.c */
FtdString       *ftd_events_sort_apply_filter (const FtdFilter *filter);
FtdString       *ftd_events_sort_parse_tags(FtdEvent *);

/* ftd_events_xml.c */
xmlNodePtr       ftd_events_xml_add_basic(FtdEvent *, xmlDocPtr);
xmlNodePtr       ftd_events_xml_add_all(FtdEvent *, xmlDocPtr);

/* ftd_eventinfo_parse.c */
FtdEvent        *ftd_eventinfo_parse(FtdString *);
FtdEvent        *ftd_eventinfo_parse_findpost(FtdString *);

#endif

==> openftd-0.99.2.tar.bz2: openftd-0.99.2/ftd_core/include/ftd_events.h <==
/* ====================================================================
 * FTD4Linux Software License, Version 1.0
 *
 * Copyright (c) 2000-2004 The FTD4Linux Development Team.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        FTD4Linux Development Team (http://www.ftd4linux.2y.net/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "FTD" and "FTD4Linux" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact alguno@ftd4linux.2y.net.
 *
 * 5. Products derived from this software may not be called "FTD4Linux",
 *    nor may "FTD4Linux" appear in their name, without prior written
 *    permission of the FTD4Linux Development Team.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE FTD4LINUX DEVELOPMENT TEAM OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef _FTD_EVENTS_H_
#define _FTD_EVENTS_H_

#include <libxml/tree.h>

#include "ftd_groups.h"

#include "ftd_events_forum.h"

/* ftd_events.c */
FtdEvent        *ftd_event_new(void);

/* ftd_events_parse.c */
FtdErrorCode     ftd_events_list_parse(FtdString *buffer, time_t *lastCheck, FtdList **chunks, FtdList **bigchunks, char **errmsg);
FtdErrorCode     ftd_events_parse(FtdString *buffer, FtdTree **ret_tree, FtdList **ret_list, char **errmsg, gboolean ignore_errors);
FtdList         *ftd_events_parse_mp3_tracks(xmlDocPtr, xmlNodePtr);

/* ftd_events_sort.c */
FtdString       *ftd_events_sort_apply_filter (const FtdFilter *filter);
FtdString       *ftd_events_sort_parse_tags(FtdEvent *);

/* ftd_events_xml.c */
xmlNodePtr       ftd_events_xml_add_basic(FtdEvent *, xmlDocPtr);
xmlNodePtr       ftd_events_xml_add_all(FtdEvent *, xmlDocPtr);

/* ftd_eventinfo_parse.c */
FtdEvent        *ftd_eventinfo_parse(FtdString *);
FtdEvent        *ftd_eventinfo_parse_findpost(FtdString *);

#endif
